import setuptools



setuptools.setup(
    name="pennylib01",
    version="0.0.1",
    author="Penny",
    author_email="penny@gmail.com",
    description="A small package of heyoo for whatsapp",
    long_description= '',
    long_description_content_type="text/markdown",
    url="https://github.com/shadaenx/pennylib",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)